==> haskell-polysemy-1.9.2.0-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polysemy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 polysemy
version:              1.9.2.0
visibility:           public
id:                   polysemy-1.9.2.0-L6QTMcwRUtW7SpUNVXci8M
key:                  polysemy-1.9.2.0-L6QTMcwRUtW7SpUNVXci8M
license:              BSD-3-Clause
copyright:            2019-2023 The Polysemy Lounge
maintainer:
    https://funprog.zulipchat.com/#narrow/stream/216942-Polysemy

author:               Sandy Maguire
homepage:             https://github.com/polysemy-research/polysemy#readme
synopsis:             Higher-order, low-boilerplate free monads.
description:
    Please see the README on GitHub at <https://github.com/polysemy-research/polysemy#readme>

category:             Language
abi:                  dc98411d8d23adef1c8a10b0448a20bb
exposed:              True
exposed-modules:
    Polysemy Polysemy.Async Polysemy.AtomicState Polysemy.Bundle
    Polysemy.Embed Polysemy.Embed.Type Polysemy.Error Polysemy.Fail
    Polysemy.Fail.Type Polysemy.Final Polysemy.Fixpoint Polysemy.IO
    Polysemy.Input Polysemy.Internal Polysemy.Internal.Bundle
    Polysemy.Internal.Combinators Polysemy.Internal.CustomErrors
    Polysemy.Internal.CustomErrors.Redefined Polysemy.Internal.Fixpoint
    Polysemy.Internal.Index Polysemy.Internal.Kind
    Polysemy.Internal.NonDet Polysemy.Internal.Scoped
    Polysemy.Internal.Sing Polysemy.Internal.Strategy
    Polysemy.Internal.TH.Common Polysemy.Internal.TH.Effect
    Polysemy.Internal.Tactics Polysemy.Internal.Union
    Polysemy.Internal.Writer Polysemy.Membership Polysemy.NonDet
    Polysemy.Opaque Polysemy.Output Polysemy.Reader Polysemy.Resource
    Polysemy.Scoped Polysemy.State Polysemy.Tagged Polysemy.Trace
    Polysemy.Writer

hidden-modules:       Polysemy.Internal.PluginLookup Paths_polysemy
import-dirs:          /usr/lib/ghc-9.4.8/site-local/polysemy-1.9.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/polysemy-1.9.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/polysemy-1.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polysemy
hs-libraries:         HSpolysemy-1.9.2.0-L6QTMcwRUtW7SpUNVXci8M
depends:
    async-2.2.5-63qhz2egf712xrTPAnr2Zj base-4.17.2.1 containers-0.6.7
    first-class-families-0.8.1.0-GHDQ6gIu3MO757TPVLJ5eT mtl-2.2.2
    stm-2.5.1.0 syb-0.7.2.4-DRmRuYXhogH1Si3eC7RXHC
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    type-errors-0.2.0.2-GA4i4bcK8DD3nRlF4H2NnC
    unagi-chan-0.4.1.4-I2QQ0yHK09E4ms54qJvBuy

haddock-interfaces:   /usr/share/doc/haskell-polysemy/html/polysemy.haddock
haddock-html:         /usr/share/doc/haskell-polysemy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polysemy-1.9.2.0-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polysemy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 polysemy
version:              1.9.2.0
visibility:           public
id:                   polysemy-1.9.2.0-HgqPw3pZfJ38e2QJs4vye9
key:                  polysemy-1.9.2.0-HgqPw3pZfJ38e2QJs4vye9
license:              BSD-3-Clause
copyright:            2019-2023 The Polysemy Lounge
maintainer:
    https://funprog.zulipchat.com/#narrow/stream/216942-Polysemy

author:               Sandy Maguire
homepage:             https://github.com/polysemy-research/polysemy#readme
synopsis:             Higher-order, low-boilerplate free monads.
description:
    Please see the README on GitHub at <https://github.com/polysemy-research/polysemy#readme>

category:             Language
abi:                  cb2f07b81a9ace298d03532dc8ce9c82
exposed:              True
exposed-modules:
    Polysemy Polysemy.Async Polysemy.AtomicState Polysemy.Bundle
    Polysemy.Embed Polysemy.Embed.Type Polysemy.Error Polysemy.Fail
    Polysemy.Fail.Type Polysemy.Final Polysemy.Fixpoint Polysemy.IO
    Polysemy.Input Polysemy.Internal Polysemy.Internal.Bundle
    Polysemy.Internal.Combinators Polysemy.Internal.CustomErrors
    Polysemy.Internal.CustomErrors.Redefined Polysemy.Internal.Fixpoint
    Polysemy.Internal.Index Polysemy.Internal.Kind
    Polysemy.Internal.NonDet Polysemy.Internal.Scoped
    Polysemy.Internal.Sing Polysemy.Internal.Strategy
    Polysemy.Internal.TH.Common Polysemy.Internal.TH.Effect
    Polysemy.Internal.Tactics Polysemy.Internal.Union
    Polysemy.Internal.Writer Polysemy.Membership Polysemy.NonDet
    Polysemy.Opaque Polysemy.Output Polysemy.Reader Polysemy.Resource
    Polysemy.Scoped Polysemy.State Polysemy.Tagged Polysemy.Trace
    Polysemy.Writer

hidden-modules:       Polysemy.Internal.PluginLookup Paths_polysemy
import-dirs:          /usr/lib/ghc-9.4.8/site-local/polysemy-1.9.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/polysemy-1.9.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/polysemy-1.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polysemy
hs-libraries:         HSpolysemy-1.9.2.0-HgqPw3pZfJ38e2QJs4vye9
depends:
    async-2.2.5-mpdT7StXVF2mjqEUwF4MR base-4.17.2.1 containers-0.6.7
    first-class-families-0.8.1.0-GHDQ6gIu3MO757TPVLJ5eT mtl-2.2.2
    stm-2.5.1.0 syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    type-errors-0.2.0.2-1O5xRfZJpDT9kM6fHZ5ceE
    unagi-chan-0.4.1.4-H5MTXnZL9Kc5mpMiYh6rqO

haddock-interfaces:   /usr/share/doc/haskell-polysemy/html/polysemy.haddock
haddock-html:         /usr/share/doc/haskell-polysemy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
